@@ -18,6 +18,7 @@ import pathlib
 import typing
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union, cast
+from urllib.parse import parse_qs
 
 import playwright._impl._network as network
 from playwright._impl._api_structures import (
@@ -53,7 +54,7 @@ if typing.TYPE_CHECKING:
 FormType = Dict[str, Union[bool, float, str]]
 DataType = Union[Any, bytes, str]
 MultipartType = Dict[str, Union[bytes, bool, float, str, FilePayload]]
-ParamsType = Dict[str, Union[bool, float, str]]
+ParamsType = Union[Dict[str, Union[bool, float, str]], str]
 
 
 class APIRequest:
@@ -404,7 +405,7 @@ class APIRequestContext(ChannelOwner):
             "fetch",
             {
                 "url": url,
-                "params": object_to_array(params),
+                "params": params_to_protocol(params),
                 "method": method,
                 "headers": serialized_headers,
                 "postData": post_data,
@@ -429,6 +430,23 @@ class APIRequestContext(ChannelOwner):
         return result
 
 
+def params_to_protocol(params: Optional[ParamsType]) -> Optional[List[NameValue]]:
+    if not params:
+        return None
+    if isinstance(params, dict):
+        return object_to_array(params)
+    if params.startswith("?"):
+        params = params[1:]
+    parsed = parse_qs(params)
+    if not parsed:
+        return None
+    out = []
+    for name, values in parsed.items():
+        for value in values:
+            out.append(NameValue(name=name, value=value))
+    return out
+
+
 def file_payload_to_json(payload: FilePayload) -> ServerFilePayload:
     return ServerFilePayload(
         name=payload["name"],
